@@ -43,7 +43,7 @@ def poly_overlap(poly1, poly2):
     for point in poly1:
         mx, my = get_midpoint(point, poly1[i])
         # midpoint = reader.Node(mx, my)
-        if contains(point, poly2) or contains(midpoint, poly2):
+        if contains(point, poly2): # or contains(midpoint, poly2)
             return True
     return False
 
